# django-cowhite-cms

A simple Django cms. Only pages available as of now.

[![Build Status](https://travis-ci.org/cowhite/django-cowhite-cms.svg?branch=master)](https://travis-ci.org/cowhite/django-cowhite-cms)
[![Coverage Status](https://coveralls.io/repos/github/cowhite/django-cowhite-cms/badge.svg?branch=master)](https://coveralls.io/github/cowhite/django-cowhite-cms?branch=master)

Installation:

pip install django-cowhite-cms